==> SexyMap-v9.2.15.zip: SexyMap/localization/itIT.lua <==

if GetLocale() ~= "itIT" then return end
local _, sm = ...
local L = sm.L
--L.dayNightButton = "Day/Night Indicator"
--L.classicLFGButton = "Classic LFG Button (When Available)"
--L.classicPVPButton = "Classic PvP Button (When Available)"
L["1. Background"] = "1. Sfondo"
L["2. Border"] = "2. Margine"
L["3. Artwork"] = "3. Immagine"
L["4. Overlay"] = "4. Sovrapposizione"
L["5. Highlight"] = "5. Evidenza"
L["Add Blend (additive)"] = "Aggiungi Miscela (aggiuntiva)"
L["Addon Buttons"] = "Pulsanti Addon"
L["A global profile already exists. You will be switched over to it and your UI will be reloaded, are you sure?"] = "Un profilo globale è già esistente. Verrà selezionato il profilo esistente e ricaricata l'Interfaccia Utente, sei sicuro?"
L["Allow SexyMap to assume drag ownership for buttons attached to the minimap. Turn this off if you have another mod that you want to use to position your minimap buttons."] = "Consenti a SexyMap di gestire i pulsanti ancorati alla Minimappa. Disabilita quest'opzione se desideri utilizzare altri Addon per la gestione di questa caratteristica."
L["Alpha Key (1-bit alpha)"] = "Chiave di Trasparenza Alpha (1-bit alpha)"
L["Always"] = "Sempre"
L["Are you sure you want to switch back to using a character specific profile? This will reload your UI."] = "Sei sicuro di voler passare nuovamente all'utilizzo del profilo specifico? Quest'operazione richiederà il ricaricamento dell'Interfaccia Utente."
L["Armored Man"] = "Uomo Armato"
L["A static amount to rotate the texture by."] = "Un valore statico di rotazione della texture."
L["Auto Zoom-Out Delay"] = "Ritardo Zoom d'Ingrandimento"
L["Backdrop Color"] = "Colore del Fondale"
L["Backdrop Insets"] = "Fondale degli Inserti"
L["Background Color"] = "Colore dello Sfondo"
L["Background/edge"] = "Sfondo/bordo"
L["Background Texture"] = "Texture dello Sfondo"
L["Blend Mode"] = "Modalità di Miscela"
L["Blend (normal)"] = "Miscela (normale)"
L["Border Color"] = "Colore del Margine"
L["Border Edge Size"] = "Dimensione del Bordo Margine"
L["Borders"] = "Margini"
L["Border Texture"] = "Texture del Margine"
L["Boss Frames"] = "Riquadri dei Boss"
L["Buttons"] = "Pulsanti"
L["Calendar"] = "Calendario"
L["Challenge Mode Button (When Available)"] = "Pulsante Modalità Sfida (Quando disponibile)"
L["Circle"] = "Cerchio"
L["Clamp to screen"] = "Ancora ai margini dello schermo"
L["Clear & start over"] = "Azzera e ricomincia"
L["Clear the current borders and start fresh"] = "Azzera i margini attuali e ricomincia"
L["Clock"] = "Orologio"
L["Coordinates"] = "Coordinate"
L["Copy a Profile"] = "Copia un Profilo"
L["Copying this profile will reload your UI, are you sure?"] = "Copiando questo profilo ricaricherai l'Interfaccia Utente, sei sicuro?"
L["Create a new border"] = "Crea un nuovo margine"
L["Current Borders"] = "Margini Correnti"
L["Default Presets"] = "Preset di Default"
L["Delete"] = "Elimina"
L["Delete a Profile"] = "Elimina un Profilo"
L["Diamond"] = "Diamante"
L["Disable (opaque)"] = "Disabilita (opaco)"
L["Disable Rotation"] = "Disabilita Rotazione"
L["Drag Radius"] = "Raggio di Trascinamento"
L["Dungeon Difficulty Indicator (When Available)"] = "Indicatore Difficoltà Spedizione (Quando Disponibile)"
L["Dynamic Buttons"] = "Pulsanti Dinamici"
L["Enable"] = "Attiva"
L["Enable a backdrop and border for the minimap. This will let you set square borders more easily."] = "Attiva un fondale ed un margine per la Minimappa. Ti consentirà d'impostare marigini quadrati più facilmente."
L["Enable a HUD minimap. This is very useful for gathering resources, but for technical reasons, the HUD map and the normal minimap can't be shown at the same time. Showing the HUD map will turn off the normal minimap."] = "Abilita una Minimappa HUD. È molto utile per la raccolta delle risorse, ma per ragioni tecniche, la mappa HUD e la normale Minimappa non possono essere visualizzate contemporaneamente. Visualizzando la mappa HUD si disattiverà la normale Minimappa."
L["Enable Coordinates"] = "Attiva Coordinate"
L["Enable Hudmap"] = "Attiva Mappa HUD"
L["Enable Minimap Fader"] = "Attiva Dissolvenza Minimappa"
L["Enter a name to create a new border. The name can be anything you like to help you identify that border."] = "Digita un nome per creare un nuovo margine. Il nome può essere qualunque cosa ti aiuti ad identificare il margine."
L["Enter the full path to a texture to use. It's recommended that you use something like |cffff6600TexBrowser|r to find textures to use."] = "Digita il percorso completo della texture da utilizzare. Si raccomanda l'utilizzo di qualcosa del tipo |cffff6600TexBrowser|r per cercare la texture da utilizzare."
L["Entry Options"] = "Voce Opzioni"
L["Faded Circle (Large)"] = "Cerchio in dissolvenza (grande)"
L["Faded Circle (Small)"] = "Cerchio in dissolvenza (piccolo)"
L["Faded Square"] = "Quadrato in dissolvenza"
L["Fader"] = "Dissolvenza"
L["Font"] = "Carattere"
L["Font Color"] = "Colore del Carattere"
L["Font Size"] = "Dimensione del Carattere"
L["Force a square texture. Fixed distortion on square textures."] = "Imponi una texture quadrata. Distorsione adattata su texture quadrate. "
-- L["Garrison Button (When Available)"] = "Garrison Button (When Available)"
L["Guild Dungeon Difficulty Indicator (When Available)"] = "Indicatore Difficoltà della Spedizione di Gilda (Quando Disponibile)"
L["Heart"] = "Cuore"
L["Height"] = "Altezza"
L["Hexagon"] = "Esagono"
L["Hide default border"] = "Nascondi il margine di default"
L["Hide the default border on the minimap."] = "Nascondi il margine di default sulla Minimappa."
L["Horizontal Nudge"] = "Colpetto Orizzontale"
L["Horizontal Position"] = "Posizione Orizzontale"
L["Hover Opacity"] = "Opacità al passaggio del mouse"
L["HUD Color"] = "Colore HUD"
L["If you zoom into the map, this feature will automatically zoom out after the selected period of time (seconds). Using a value of 0 will disable Auto Zoom-Out."] = "Se ingrandisci nella mappa, questa caratteristica rimpicciolirà la stessa automaticamente dopo un periodo di tempo (in secondi) specificato. Impostando 0 si disattiverà tale caratteristica."
L["Keybinding"] = "Assegnazione Tasti"
L["Layer"] = "Livello"
L["Let SexyMap control button visibility"] = "Consenti a SexyMap la gestione della visibilità del pulsante"
L["Let SexyMap handle button dragging"] = "Consenti a SexyMap la gestione dell'ancoraggio del pulsante"
L["Lock Button Dragging"] = "Blocca Pulsante d'Ancoraggio"
L["Lock Minimap"] = "Blocca Minimappa"
L["Map Button"] = "Pulsante Mappa"
L["Minimap shape"] = "Forma Minimappa"
L["Mod Blend (modulative)"] = "Mod Miscela (modulativo)"
L["Movers"] = "Spostabili"
L["Name"] = "Nome"
L["Never"] = "Mai"
L["New Mail Indicator (When Available)"] = "Indicatore Posta in Arrivo (Quando Disponibile)"
L["No global profile exists. Your current profile will be copied over and used as the global profile, are you sure? This will also reload your UI."] = "Nessun profilo globale esistente. Il profilo corrente verrà copiato ed utilizzato come profilo globale, sei sicuro? Quest'operazione richiederà il ricaricamento dell'Interfaccia Utente."
L["Normal Opacity"] = "Opacità Normale"
L["Objectives Tracker"] = "Tracciatore Obiettivi"
L["Octagon"] = "Ottagono"
L["On Hover"] = "Al passaggio del mouse"
L["Opacity"] = "Opacità"
L["Open TexBrowser"] = "Apri Texbrowser"
L["Ping"] = "Ping"
L["Preset"] = "Preset"
L["Prevent the minimap from being moved off the screen"] = "Impedisci l'ancoraggio della Minimappa oltre i margini dello schermo"
L["Profiles"] = "Profili"
L["Queue Status (PvP/LFG) Button (When Available)"] = "Pulsante Stato d'Attesa (PvP/Ricerca Gruppo) (Quando Disponibile)"
L["Quickly change the look of your minimap by using a minimap preset."] = "Cambia rapidamente l'aspetto della Minimappa utilizzando un preset."
L["Really delete this border?"] = "Sei sicuro di voler eliminare questo margine?"
L["Really delete this preset? This can't be undone."] = "Sei sicuro di voler eliminare questo preset? Quest'azione è irreversibile."
L["Really delete this profile?"] = "Sei sicuro di voler eliminare questo profilo?"
L["(Requires button visibility control in the Buttons menu)"] = "(Richiede il controllo della visibilita del pulsante nel menù Pulsanti)"
L["Reset Current Profile"] = "Reset del Profilo Corrente"
L["Resetting this profile will reload your UI, are you sure?"] = "Resettando questo profilo ricaricherai l'Interfaccia Utente, sei sicuro?"
L["Right Click Configure"] = "Configura Tasto Destro"
L["Right clicking the map will open the SexyMap options"] = "Cliccando la mappa con il tasto destro aprirà le opzioni di SexyMap"
L["Rotation Speed (seconds)"] = "Velocità di Rotazione (secondi)"
L["Rounded - Bottom"] = "Arrotondato - Inferiore"
L["Rounded - Bottom Left"] = "Arrotondato - Inferiore Sinistro"
L["Rounded - Bottom Right"] = "Arrotondato - Inferiore Destro"
L["Rounded - Left"] = "Arrotondato - Sinistro"
L["Rounded - Right"] = "Arrotondato - Destro"
L["Rounded - Top"] = "Arrotondato - Superiore"
L["Rounded - Top Left"] = "Arrotondato - Superiore Sinistro"
L["Rounded - Top Right"] = "Arrotondato - Superiore Destro"
L["Route 66"] = "Route 66"
L["Save current settings as preset..."] = "Salva le impostazioni correnti come un preset..."
L["Scale"] = "Scala"
L["Select a preset to load settings from. This will erase any of your current borders."] = "Seleziona un preset da cui attingere. Quest'operazione eliminerà ogni margine attuale."
L["Select preset to load"] = "Seleziona preset da caricare"
L["SharedMedia Border"] = "Margine SharedMedia"
L["SharedMedia Texture"] = "Texture SharedMedia"
L["Show inside chat"] = "Visualizza nella chat"
L["Show North Tag"] = "Visualizza Tag del Nord"
L["Show on minimap"] = "Visualizza sulla Minimappa"
L["Show %s:"] = "Visualizza %s:"
L["Show who pinged"] = "Visualizza chi ha pingato"
L["Snowflake"] = "Fiocco di neve"
L["Spice up your minimap with some sexy options."] = "Vivacizza la Minimappa con alcune opzioni sexy."
L["Square"] = "Quadrato"
L["Standard Buttons"] = "Pulsanti Standard"
L["Static Rotation"] = "Rotazione Statica"
L["TexBrowser Not Installed"] = "TexBrowser Non Installato"
L["Text Color"] = "Colore del Testo"
L["Texture"] = "Texture"
L["Texture Options"] = "Opzioni Texture"
L["Texture Path"] = "Percorso della Texture"
L["Texture Tint"] = "Tinta della Texture"
L["Text Width"] = "Larghezza del Testo"
L["The HudMap supports several addons. If you have any of the addons below installed, they will be shown on the HudMap."] = "La Mappa HUD supporta alcuni Addon. Se possiedi uno qualsiasi degli Addon elencati qui in basso, verrano visualizzati sulla Mappa HUD."
L["The time it takes (in seconds) to complete one rotation. A setting of 0 turns off rotation."] = "Il tempo impiegato (in secondi) per completare una rotazione. Impostando 0 si disattiva la rotazione."
L["This will wipe out any current settings!"] = "Questo eliminerà ogni impostazione corrente!"
L["Tile Background"] = "Sfondo del Tile"
L["Tile Size"] = "Dimensione del Tile"
L["Toggle HudMap On/Off"] = "Nascondi Mappa HUD (On/Off)"
L["Tracking Button"] = "Pulsante di Tracciatura"
L["Turn this off if you want another mod to handle which buttons are visible on the minimap."] = "Disattiva questa caratteristica se desideri far gestire i pulsanti visualizzabili sulla Minimappa da un'altro Addon."
L["Use Global Profile"] = "Utilizza Profilo Globale"
L["User-Submitted Presets"] = "Preset Inviati dagli Utenti"
L["Use the global profile if you want the same look on every character, or use a character-specific profile for a unique look on each character."] = "Usa il profilo globale se desideri lo stesso aspetto su qualsiasi personaggio, oppura usa un profilo specifico per ogni personaggio se preferisci un aspetto differente per ogni personaggio."
L["Vehicle Seat"] = "Sedile del Veicolo"
L["Vertical Nudge"] = "Colpetto Verticale"
L["Vertical Position"] = "Posizione Verticale"
L["Visibility"] = "Visibilità"
L["Width"] = "Larghezza"
L["You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."] = "Puoi impostare qualsiasi file di sfondo e di margine per la Minimappa, con qualsiasi cornice. Questa caratteristica risulta utile nel caso desideri realizzare un fondale quadrato statico per la Minimappa."
L["Zone Text"] = "Testo Zona"
L["Zoom In Button"] = "Zoom d'Ingrandimento"
L["Zoom Out Button"] = "Pulsante Zoom d'Ingrandimento"

-- Coordinates.lua
--L.updateRate = "Update Rate (seconds)"
--L.updateRateDesc = "The lower the value, the faster the coordinates will update, but the more memory and CPU will be consumed due to asking the game for fresh coordinate data."
--L.Precision = "Precision"

-- Movers.lua
--L.moversDescription = "Enable the ability to move specific UI elements."
--L.disableWarning = "Disabling this will temporarily show the loading screen. Are you sure?"
--L.enableObject = "Enable %s"
--L.lockObject = "Lock %s"
L.pvpCaptureBar = "PvP Barre di Cattura"
--L.buffs = "Buffs/Debuffs"
--L.topCenterObjectivesWidget = "Top-Screen Objective/PvP Tracker"

==> SexyMap-v11.0.1.zip: SexyMap/localization/itIT.lua <==

if GetLocale() ~= "itIT" then return end
local _, sm = ...
local L = sm.L
--L.dayNightButton = "Day/Night Indicator"
--L.classicLFGButton = "Classic LFG Button (When Available)"
--L.classicPVPButton = "Classic PvP Button (When Available)"
L["1. Background"] = "1. Sfondo"
L["2. Border"] = "2. Margine"
L["3. Artwork"] = "3. Immagine"
L["4. Overlay"] = "4. Sovrapposizione"
L["5. Highlight"] = "5. Evidenza"
L["Add Blend (additive)"] = "Aggiungi Miscela (aggiuntiva)"
L["Addon Buttons"] = "Pulsanti Addon"
L["A global profile already exists. You will be switched over to it and your UI will be reloaded, are you sure?"] = "Un profilo globale è già esistente. Verrà selezionato il profilo esistente e ricaricata l'Interfaccia Utente, sei sicuro?"
L["Allow SexyMap to assume drag ownership for buttons attached to the minimap. Turn this off if you have another mod that you want to use to position your minimap buttons."] = "Consenti a SexyMap di gestire i pulsanti ancorati alla Minimappa. Disabilita quest'opzione se desideri utilizzare altri Addon per la gestione di questa caratteristica."
L["Alpha Key (1-bit alpha)"] = "Chiave di Trasparenza Alpha (1-bit alpha)"
L["Always"] = "Sempre"
L["Are you sure you want to switch back to using a character specific profile? This will reload your UI."] = "Sei sicuro di voler passare nuovamente all'utilizzo del profilo specifico? Quest'operazione richiederà il ricaricamento dell'Interfaccia Utente."
L["Armored Man"] = "Uomo Armato"
L["A static amount to rotate the texture by."] = "Un valore statico di rotazione della texture."
L["Auto Zoom-Out Delay"] = "Ritardo Zoom d'Ingrandimento"
L["Backdrop Color"] = "Colore del Fondale"
L["Backdrop Insets"] = "Fondale degli Inserti"
L["Background Color"] = "Colore dello Sfondo"
L["Background/edge"] = "Sfondo/bordo"
L["Background Texture"] = "Texture dello Sfondo"
L["Blend Mode"] = "Modalità di Miscela"
L["Blend (normal)"] = "Miscela (normale)"
L["Border Color"] = "Colore del Margine"
L["Border Edge Size"] = "Dimensione del Bordo Margine"
L["Borders"] = "Margini"
L["Border Texture"] = "Texture del Margine"
L["Boss Frames"] = "Riquadri dei Boss"
L["Buttons"] = "Pulsanti"
L["Calendar"] = "Calendario"
L["Challenge Mode Button (When Available)"] = "Pulsante Modalità Sfida (Quando disponibile)"
L["Circle"] = "Cerchio"
L["Clamp to screen"] = "Ancora ai margini dello schermo"
L["Clear & start over"] = "Azzera e ricomincia"
L["Clear the current borders and start fresh"] = "Azzera i margini attuali e ricomincia"
L["Clock"] = "Orologio"
L["Coordinates"] = "Coordinate"
L["Copy a Profile"] = "Copia un Profilo"
L["Copying this profile will reload your UI, are you sure?"] = "Copiando questo profilo ricaricherai l'Interfaccia Utente, sei sicuro?"
L["Create a new border"] = "Crea un nuovo margine"
L["Current Borders"] = "Margini Correnti"
L["Default Presets"] = "Preset di Default"
L["Delete"] = "Elimina"
L["Delete a Profile"] = "Elimina un Profilo"
L["Diamond"] = "Diamante"
L["Disable (opaque)"] = "Disabilita (opaco)"
L["Disable Rotation"] = "Disabilita Rotazione"
L["Drag Radius"] = "Raggio di Trascinamento"
L["Dungeon Difficulty Indicator (When Available)"] = "Indicatore Difficoltà Spedizione (Quando Disponibile)"
L["Dynamic Buttons"] = "Pulsanti Dinamici"
L["Enable"] = "Attiva"
L["Enable a backdrop and border for the minimap. This will let you set square borders more easily."] = "Attiva un fondale ed un margine per la Minimappa. Ti consentirà d'impostare marigini quadrati più facilmente."
L["Enable a HUD minimap. This is very useful for gathering resources, but for technical reasons, the HUD map and the normal minimap can't be shown at the same time. Showing the HUD map will turn off the normal minimap."] = "Abilita una Minimappa HUD. È molto utile per la raccolta delle risorse, ma per ragioni tecniche, la mappa HUD e la normale Minimappa non possono essere visualizzate contemporaneamente. Visualizzando la mappa HUD si disattiverà la normale Minimappa."
L["Enable Coordinates"] = "Attiva Coordinate"
L["Enable Hudmap"] = "Attiva Mappa HUD"
L["Enable Minimap Fader"] = "Attiva Dissolvenza Minimappa"
L["Enter a name to create a new border. The name can be anything you like to help you identify that border."] = "Digita un nome per creare un nuovo margine. Il nome può essere qualunque cosa ti aiuti ad identificare il margine."
L["Enter the full path to a texture to use. It's recommended that you use something like |cffff6600TexBrowser|r to find textures to use."] = "Digita il percorso completo della texture da utilizzare. Si raccomanda l'utilizzo di qualcosa del tipo |cffff6600TexBrowser|r per cercare la texture da utilizzare."
L["Entry Options"] = "Voce Opzioni"
L["Faded Circle (Large)"] = "Cerchio in dissolvenza (grande)"
L["Faded Circle (Small)"] = "Cerchio in dissolvenza (piccolo)"
L["Faded Square"] = "Quadrato in dissolvenza"
L["Fader"] = "Dissolvenza"
L["Font"] = "Carattere"
L["Font Color"] = "Colore del Carattere"
L["Font Size"] = "Dimensione del Carattere"
L["Force a square texture. Fixed distortion on square textures."] = "Imponi una texture quadrata. Distorsione adattata su texture quadrate. "
-- L["Garrison Button (When Available)"] = "Garrison Button (When Available)"
L["Guild Dungeon Difficulty Indicator (When Available)"] = "Indicatore Difficoltà della Spedizione di Gilda (Quando Disponibile)"
L["Heart"] = "Cuore"
L["Height"] = "Altezza"
L["Hexagon"] = "Esagono"
L["Hide default border"] = "Nascondi il margine di default"
L["Hide the default border on the minimap."] = "Nascondi il margine di default sulla Minimappa."
L["Horizontal Nudge"] = "Colpetto Orizzontale"
L["Horizontal Position"] = "Posizione Orizzontale"
L["Hover Opacity"] = "Opacità al passaggio del mouse"
L["HUD Color"] = "Colore HUD"
L["If you zoom into the map, this feature will automatically zoom out after the selected period of time (seconds). Using a value of 0 will disable Auto Zoom-Out."] = "Se ingrandisci nella mappa, questa caratteristica rimpicciolirà la stessa automaticamente dopo un periodo di tempo (in secondi) specificato. Impostando 0 si disattiverà tale caratteristica."
L["Keybinding"] = "Assegnazione Tasti"
L["Layer"] = "Livello"
L["Let SexyMap control button visibility"] = "Consenti a SexyMap la gestione della visibilità del pulsante"
L["Let SexyMap handle button dragging"] = "Consenti a SexyMap la gestione dell'ancoraggio del pulsante"
L["Lock Button Dragging"] = "Blocca Pulsante d'Ancoraggio"
L["Lock Minimap"] = "Blocca Minimappa"
L["Map Button"] = "Pulsante Mappa"
L["Minimap shape"] = "Forma Minimappa"
L["Mod Blend (modulative)"] = "Mod Miscela (modulativo)"
L["Movers"] = "Spostabili"
L["Name"] = "Nome"
L["Never"] = "Mai"
L["New Mail Indicator (When Available)"] = "Indicatore Posta in Arrivo (Quando Disponibile)"
L["No global profile exists. Your current profile will be copied over and used as the global profile, are you sure? This will also reload your UI."] = "Nessun profilo globale esistente. Il profilo corrente verrà copiato ed utilizzato come profilo globale, sei sicuro? Quest'operazione richiederà il ricaricamento dell'Interfaccia Utente."
L["Normal Opacity"] = "Opacità Normale"
L["Objectives Tracker"] = "Tracciatore Obiettivi"
L["Octagon"] = "Ottagono"
L["On Hover"] = "Al passaggio del mouse"
L["Opacity"] = "Opacità"
L["Open TexBrowser"] = "Apri Texbrowser"
L["Ping"] = "Ping"
L["Preset"] = "Preset"
L["Prevent the minimap from being moved off the screen"] = "Impedisci l'ancoraggio della Minimappa oltre i margini dello schermo"
L["Profiles"] = "Profili"
L["Queue Status (PvP/LFG) Button (When Available)"] = "Pulsante Stato d'Attesa (PvP/Ricerca Gruppo) (Quando Disponibile)"
L["Quickly change the look of your minimap by using a minimap preset."] = "Cambia rapidamente l'aspetto della Minimappa utilizzando un preset."
L["Really delete this border?"] = "Sei sicuro di voler eliminare questo margine?"
L["Really delete this preset? This can't be undone."] = "Sei sicuro di voler eliminare questo preset? Quest'azione è irreversibile."
L["Really delete this profile?"] = "Sei sicuro di voler eliminare questo profilo?"
L["(Requires button visibility control in the Buttons menu)"] = "(Richiede il controllo della visibilita del pulsante nel menù Pulsanti)"
L["Reset Current Profile"] = "Reset del Profilo Corrente"
L["Resetting this profile will reload your UI, are you sure?"] = "Resettando questo profilo ricaricherai l'Interfaccia Utente, sei sicuro?"
L["Right Click Configure"] = "Configura Tasto Destro"
L["Right clicking the map will open the SexyMap options"] = "Cliccando la mappa con il tasto destro aprirà le opzioni di SexyMap"
L["Rotation Speed (seconds)"] = "Velocità di Rotazione (secondi)"
L["Rounded - Bottom"] = "Arrotondato - Inferiore"
L["Rounded - Bottom Left"] = "Arrotondato - Inferiore Sinistro"
L["Rounded - Bottom Right"] = "Arrotondato - Inferiore Destro"
L["Rounded - Left"] = "Arrotondato - Sinistro"
L["Rounded - Right"] = "Arrotondato - Destro"
L["Rounded - Top"] = "Arrotondato - Superiore"
L["Rounded - Top Left"] = "Arrotondato - Superiore Sinistro"
L["Rounded - Top Right"] = "Arrotondato - Superiore Destro"
L["Route 66"] = "Route 66"
L["Save current settings as preset..."] = "Salva le impostazioni correnti come un preset..."
L["Scale"] = "Scala"
L["Select a preset to load settings from. This will erase any of your current borders."] = "Seleziona un preset da cui attingere. Quest'operazione eliminerà ogni margine attuale."
L["Select preset to load"] = "Seleziona preset da caricare"
L["SharedMedia Border"] = "Margine SharedMedia"
L["SharedMedia Texture"] = "Texture SharedMedia"
L["Show inside chat"] = "Visualizza nella chat"
L["Show North Tag"] = "Visualizza Tag del Nord"
L["Show on minimap"] = "Visualizza sulla Minimappa"
L["Show %s:"] = "Visualizza %s:"
L["Show who pinged"] = "Visualizza chi ha pingato"
L["Snowflake"] = "Fiocco di neve"
L["Spice up your minimap with some sexy options."] = "Vivacizza la Minimappa con alcune opzioni sexy."
L["Square"] = "Quadrato"
L["Standard Buttons"] = "Pulsanti Standard"
L["Static Rotation"] = "Rotazione Statica"
L["TexBrowser Not Installed"] = "TexBrowser Non Installato"
L["Text Color"] = "Colore del Testo"
L["Texture"] = "Texture"
L["Texture Options"] = "Opzioni Texture"
L["Texture Path"] = "Percorso della Texture"
L["Texture Tint"] = "Tinta della Texture"
L["Text Width"] = "Larghezza del Testo"
L["The HudMap supports several addons. If you have any of the addons below installed, they will be shown on the HudMap."] = "La Mappa HUD supporta alcuni Addon. Se possiedi uno qualsiasi degli Addon elencati qui in basso, verrano visualizzati sulla Mappa HUD."
L["The time it takes (in seconds) to complete one rotation. A setting of 0 turns off rotation."] = "Il tempo impiegato (in secondi) per completare una rotazione. Impostando 0 si disattiva la rotazione."
L["This will wipe out any current settings!"] = "Questo eliminerà ogni impostazione corrente!"
L["Tile Background"] = "Sfondo del Tile"
L["Tile Size"] = "Dimensione del Tile"
L["Toggle HudMap On/Off"] = "Nascondi Mappa HUD (On/Off)"
L["Tracking Button"] = "Pulsante di Tracciatura"
L["Turn this off if you want another mod to handle which buttons are visible on the minimap."] = "Disattiva questa caratteristica se desideri far gestire i pulsanti visualizzabili sulla Minimappa da un'altro Addon."
L["Use Global Profile"] = "Utilizza Profilo Globale"
L["User-Submitted Presets"] = "Preset Inviati dagli Utenti"
L["Use the global profile if you want the same look on every character, or use a character-specific profile for a unique look on each character."] = "Usa il profilo globale se desideri lo stesso aspetto su qualsiasi personaggio, oppura usa un profilo specifico per ogni personaggio se preferisci un aspetto differente per ogni personaggio."
L["Vehicle Seat"] = "Sedile del Veicolo"
L["Vertical Nudge"] = "Colpetto Verticale"
L["Vertical Position"] = "Posizione Verticale"
L["Visibility"] = "Visibilità"
L["Width"] = "Larghezza"
L["You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."] = "Puoi impostare qualsiasi file di sfondo e di margine per la Minimappa, con qualsiasi cornice. Questa caratteristica risulta utile nel caso desideri realizzare un fondale quadrato statico per la Minimappa."
L["Zone Text"] = "Testo Zona"
L["Zoom In Button"] = "Zoom d'Ingrandimento"
L["Zoom Out Button"] = "Pulsante Zoom d'Ingrandimento"

-- Buttons.lua
--L.addonCompartment = "Addon Compartment"
--L.craftingOrder = "Crafting Order (When Available)"

-- Coordinates.lua
--L.updateRate = "Update Rate (seconds)"
--L.updateRateDesc = "The lower the value, the faster the coordinates will update, but the more memory and CPU will be consumed due to asking the game for fresh coordinate data."
--L.Precision = "Precision"

-- Movers.lua
--L.moversDescription = "Enable the ability to move specific UI elements."
--L.disableWarning = "Disabling this will temporarily show the loading screen. Are you sure?"
--L.enableObject = "Enable %s"
--L.lockObject = "Lock %s"
L.pvpCaptureBar = "PvP Barre di Cattura"
--L.buffs = "Buffs/Debuffs"
--L.topCenterObjectivesWidget = "Top-Screen Objective/PvP Tracker"
--L.zoneTextCombatClick = "|cFF33FF99SexyMap|r: To toggle the World Map in combat, you must enable the feature in the Zone Text options."
--L.zoneTextSecureButtonEnable = "Allow clicking in combat"
--L.zoneTextSecureButtonEnableDesc = "Normally you can click the Zone Text to toggle your World Map, but not in combat without this feature enabled.\n\n|cffff0000WARNING!|r Don't enable this feature unless you understand what it does. Turning this on will prevent ALL of your addons from making certain changes to your minimap in combat, such as moving it or hiding it."
L.none = "Nessuno"
L.thin = "Fine"
L.thick = "Spesso"
L.outline = "Sottolineato"
L.monochrome = "Monocromatico"
L.monochromeDesc = "Abilita il flag monocromatico, rimuovendo ogni effetto di smussatura degli angoli dei caratteri."
